# grunt-legacy-util
> deprecated utilities from grunt

[![Build Status](https://secure.travis-ci.org/gruntjs/grunt-legacy-util.png?branch=master)](http://travis-ci.org/gruntjs/grunt-legacy-util)
[![Built with Grunt](https://cdn.gruntjs.com/builtwith.png)](http://gruntjs.com/)


With the next major release of Grunt, we will no longer support these APIs.  Where possible, please use the recommended modules in their place.  If you would like to support or improve any of these APIs, please notify us when you have published a backwards compatible npm module&mdash;we will then recommend its usage here.

`grunt.util.namespace` use [getobject]  
`grunt.util.hooker` use [hooker]  
`grunt.util.async` use [async]  
`grunt.util._` use [lodash]  
`grunt.util.exit` use [exit]  
`grunt.util.callbackify`  
`grunt.util.error`  
`grunt.util.linefeed`  
`grunt.util.normalizelf`  
`grunt.util.kindOf` use [lodash]  
`grunt.util.toArray`
`grunt.util.repeat`  
`grunt.util.pluralize`  
`grunt.util.recurse` use [traverse]  
`grunt.util.spawn`  

[getobject]: https://www.npmjs.org/package/getobject
[hooker]: https://www.npmjs.org/package/hooker
[async]: https://www.npmjs.org/package/async
[lodash]: https://www.npmjs.org/package/lodash
[exit]: https://www.npmjs.org/package/exit
[traverse]: https://www.npmjs.org/package/traverse
